django-inviter2
===============

[![Build Status](https://travis-ci.org/mjschultz/django-inviter2.png)](https://travis-ci.org/mjschultz/django-inviter2)
[![Coverage Status](https://coveralls.io/repos/mjschultz/django-inviter2/badge.png?branch=master)](https://coveralls.io/r/mjschultz/django-inviter2?branch=master)

Let your users invite new users.

Useful if you want your webapp to be in a private beta mode or for only permitting access to known users.

Version Support
---------------

- Django 1.4, 1.5, and 1.6 (requires Python 2.6 or 2.7)
- Django 1.5 and 1.6 (requires Python 2.6, 2.7, 3.2, or 3.3)

History
-------

This is a fork of [django-inviter](http://www.caffeinehit.com/work/code/django-inviter).


Documentation is available via [Read the Docs](http://django-inviter2.readthedocs.org/).

